@@ -79,28 +79,40 @@ class MathMathML extends MathRenderer {
 	 * @see MathRenderer::render()
 	*/
 	public function render( $forceReRendering = false ) {
-		if ( in_array( $this->inputType, $this->restbaseInputTypes ) && $this->mode == 'mathml' ) {
-			if ( !$this->rbi ){
-				$this->rbi = new MathRestbaseInterface( $this->getTex(), $this->getInputType() );
+		global $wgMathFullRestbaseURL;
+		try {
+			if ( $forceReRendering ) {
+				$this->setPurge( true );
 			}
-			$rbi = $this->rbi;
-			if ( $rbi->getSuccess() ) {
-				$this->mathml = $rbi->getMathML();
-				$this->mathoidStyle = $rbi->getMathoidStyle();
-				$this->svgPath = $rbi->getFullSvgUrl();
-			} elseif ( $this->lastError === '' ) {
-				$this->doCheck();
+			if ( in_array( $this->inputType, $this->restbaseInputTypes ) &&
+				$this->mode == 'mathml'
+			) {
+				if ( !$this->rbi ) {
+					$this->rbi =
+						new MathRestbaseInterface( $this->getTex(), $this->getInputType() );
+					$this->rbi->setPurge( $this->isPurge() );
+				}
+				$rbi = $this->rbi;
+				if ( $rbi->getSuccess() ) {
+					$this->mathml = $rbi->getMathML();
+					$this->mathoidStyle = $rbi->getMathoidStyle();
+					$this->svgPath = $rbi->getFullSvgUrl();
+				} elseif ( $this->lastError === '' ) {
+					$this->doCheck();
+				}
+				$this->changed = false;
+				return $rbi->getSuccess();
 			}
-			$this->changed = false;
-			return $rbi->getSuccess();
+			if ( $this->renderingRequired() ) {
+				return $this->doRender();
+			}
+			return true;
+		} catch ( Exception $e ) {
+			$this->lastError = $this->getError( 'math_mathoid_error',
+				$wgMathFullRestbaseURL, $e->getMessage() );
+			LoggerFactory::getInstance( 'Math' )->error( $e->getMessage(), [ $e, $this ] );
+			return false;
 		}
-		if ( $forceReRendering ) {
-			$this->setPurge( true );
-		}
-		if ( $this->renderingRequired() ) {
-			return $this->doRender();
-		}
-		return true;
 	}
 
 	/**
@@ -374,9 +386,9 @@ class MathMathML extends MathRenderer {
 	 * @return string XML the image html tag
 	 */
 	private function getFallbackImage( $noRender = false, $classOverride = false ) {
-		$url = $this->getFallbackImageUrl( $noRender );
-
-		$attribs = [];
+		$attribs = [
+			'src' => $this->getFallbackImageUrl( $noRender )
+		];
 		if ( $classOverride === false ) { // $class = '' suppresses class attribute
 			$class = $this->getClassName( true );
 		} else {
@@ -385,18 +397,14 @@ class MathMathML extends MathRenderer {
 		if ( ! $this->mathoidStyle ) {
 			$this->correctSvgStyle( $this->mathoidStyle );
 		}
-		// TODO: move the common styles to the global stylesheet!
-		$style = 'background-image: url(\''. $url .
-			 '\'); background-repeat: no-repeat; background-size: 100% 100%; '.
-			$this->mathoidStyle;
 		if ( $class ) {
 			$attribs['class'] = $class;
 		}
 
-		// Don't use an empty span, as that is going to be stripped by HTML tidy
-		// when enabled (which is true in production).
-		return Xml::element( 'meta', $this->getAttributes(
-			'span', $attribs, [ 'aria-hidden' => 'true', 'style' => $style
+		return Xml::element( 'img', $this->getAttributes( 'span', $attribs, [
+			'aria-hidden' => 'true',
+			'style' => $this->mathoidStyle,
+			'alt' => $this->tex
 		] ) );
 	}
 
