@@ -1,20 +1,44 @@
 <?php
+
 /**
  * Test the database access and core functionality of MathRenderer.
  *
+ * @covers MathRenderer
+ *
  * @group Math
+ *
+ * @licence GNU GPL v2+
  */
 class MathRendererTest extends MediaWikiTestCase {
 	const SOME_TEX = "a+b";
 	const TEXVCCHECK_INPUT = '\forall \epsilon \exist \delta';
 	const TEXVCCHECK_OUTPUT = '\forall \epsilon \exists \delta '; // be aware of the s at exists
+
+	protected static $hasRestbase;
+
+	public static function setUpBeforeClass() {
+		$rbi = new MathRestbaseInterface();
+		self::$hasRestbase = $rbi->checkBackend( true );
+	}
+
+	/**
+	 * Sets up the fixture, for example, opens a network connection.
+	 * This method is called before a test is executed.
+	 */
+	protected function setUp() {
+		parent::setUp();
+		if ( !self::$hasRestbase ) {
+			$this->markTestSkipped( "Can not connect to Restbase Math interface." );
+		}
+	}
+
 	/**
 	 * Checks the tex and hash functions
 	 * @covers MathRenderer::getTex()
 	 * @covers MathRenderer::__construct()
 	 */
 	public function testBasics() {
-		$renderer = $this->getMockForAbstractClass( 'MathRenderer', array( self::SOME_TEX ) );
+		$renderer = $this->getMockForAbstractClass( 'MathRenderer', [ self::SOME_TEX ] );
 		// check if the TeX input was corretly passed to the class
 		$this->assertEquals( self::SOME_TEX, $renderer->getTex(), "test getTex" );
 		$this->assertEquals( $renderer->isChanged(), false, "test if changed is initially false" );
@@ -26,12 +50,12 @@ class MathRendererTest extends MediaWikiTestCase {
 	 */
 	public function testWriteCacheSkip() {
 		$renderer =
-			$this->getMockBuilder( 'MathRenderer' )->setMethods( array(
+			$this->getMockBuilder( 'MathRenderer' )->setMethods( [
 					'writeToDatabase',
 					'render',
 					'getMathTableName',
 					'getHtmlOutput'
-				) )->disableOriginalConstructor()->getMock();
+				] )->disableOriginalConstructor()->getMock();
 		$renderer->expects( $this->never() )->method( 'writeToDatabase' );
 		$renderer->writeCache();
 	}
@@ -42,99 +66,99 @@ class MathRendererTest extends MediaWikiTestCase {
 	 */
 	public function testWriteCache() {
 		$renderer =
-			$this->getMockBuilder( 'MathRenderer' )->setMethods( array(
+			$this->getMockBuilder( 'MathRenderer' )->setMethods( [
 					'writeToDatabase',
 					'render',
 					'getMathTableName',
 					'getHtmlOutput'
-				) )->disableOriginalConstructor()->getMock();
+				] )->disableOriginalConstructor()->getMock();
 		$renderer->expects( $this->never() )->method( 'writeToDatabase' );
 		$renderer->writeCache();
 	}
 
 	public function testSetPurge() {
 		$renderer =
-			$this->getMockBuilder( 'MathRenderer' )->setMethods( array(
+			$this->getMockBuilder( 'MathRenderer' )->setMethods( [
 					'render',
 					'getMathTableName',
 					'getHtmlOutput'
-				) )->disableOriginalConstructor()->getMock();
+				] )->disableOriginalConstructor()->getMock();
 		$renderer->setPurge();
 		$this->assertEquals( $renderer->isPurge(), true, "Test purge." );
 
 	}
 
-	public function testCheckingAlways() {
-		$this->setMwGlobals( "wgMathDisableTexFilter", 'always' );
+	public function testDisableCheckingAlways() {
+		$this->setMwGlobals( "wgMathDisableTexFilter", 'never' );
 		$renderer =
-			$this->getMockBuilder( 'MathRenderer' )->setMethods( array(
+			$this->getMockBuilder( 'MathRenderer' )->setMethods( [
 					'render',
 					'getMathTableName',
 					'getHtmlOutput',
 					'readFromDatabase',
 					'setTex'
-				) )->setConstructorArgs( array( self::TEXVCCHECK_INPUT ) )->getMock();
+				] )->setConstructorArgs( [ self::TEXVCCHECK_INPUT ] )->getMock();
 		$renderer->expects( $this->never() )->method( 'readFromDatabase' );
 		$renderer->expects( $this->once() )->method( 'setTex' )->with( self::TEXVCCHECK_OUTPUT );
 
-		$this->assertEquals( $renderer->checkTex(), true );
+		$this->assertEquals( $renderer->checkTeX(), true );
 		// now setTex sould not be called again
-		$this->assertEquals( $renderer->checkTex(), true );
+		$this->assertEquals( $renderer->checkTeX(), true );
 
 	}
 
-	public function testCheckingNever() {
-		$this->setMwGlobals( "wgMathDisableTexFilter", 'never' );
+	public function testDisableCheckingNever() {
+		$this->setMwGlobals( "wgMathDisableTexFilter", 'always' );
 		$renderer =
-			$this->getMockBuilder( 'MathRenderer' )->setMethods( array(
+			$this->getMockBuilder( 'MathRenderer' )->setMethods( [
 					'render',
 					'getMathTableName',
 					'getHtmlOutput',
 					'readFromDatabase',
 					'setTex'
-				) )->setConstructorArgs( array( self::TEXVCCHECK_INPUT ) )->getMock();
+				] )->setConstructorArgs( [ self::TEXVCCHECK_INPUT ] )->getMock();
 		$renderer->expects( $this->never() )->method( 'readFromDatabase' );
 		$renderer->expects( $this->never() )->method( 'setTex' );
 
-		$this->assertEquals( $renderer->checkTex(), true );
+		$this->assertEquals( $renderer->checkTeX(), true );
 	}
 
 	public function testCheckingNewUnknown() {
 		$this->setMwGlobals( "wgMathDisableTexFilter", 'new' );
 		$renderer =
-			$this->getMockBuilder( 'MathRenderer' )->setMethods( array(
+			$this->getMockBuilder( 'MathRenderer' )->setMethods( [
 					'render',
 					'getMathTableName',
 					'getHtmlOutput',
 					'readFromDatabase',
 					'setTex'
-				) )->setConstructorArgs( array( self::TEXVCCHECK_INPUT ) )->getMock();
+				] )->setConstructorArgs( [ self::TEXVCCHECK_INPUT ] )->getMock();
 		$renderer->expects( $this->once() )->method( 'readFromDatabase' )
 			->will( $this->returnValue( false ) );
 		$renderer->expects( $this->once() )->method( 'setTex' )->with( self::TEXVCCHECK_OUTPUT );
 
-		$this->assertEquals( $renderer->checkTex(), true );
+		$this->assertEquals( $renderer->checkTeX(), true );
 		// now setTex sould not be called again
-		$this->assertEquals( $renderer->checkTex(), true );
+		$this->assertEquals( $renderer->checkTeX(), true );
 	}
 
 	public function testCheckingNewKnown() {
 		$this->setMwGlobals( "wgMathDisableTexFilter", 'new' );
 		$renderer =
-			$this->getMockBuilder( 'MathRenderer' )->setMethods( array(
+			$this->getMockBuilder( 'MathRenderer' )->setMethods( [
 					'render',
 					'getMathTableName',
 					'getHtmlOutput',
 					'readFromDatabase',
 					'setTex'
-				) )->setConstructorArgs( array( self::TEXVCCHECK_INPUT ) )->getMock();
+				] )->setConstructorArgs( [ self::TEXVCCHECK_INPUT ] )->getMock();
 		$renderer->expects( $this->exactly( 2 ) )->method( 'readFromDatabase' )
 			->will( $this->returnValue( true ) );
 		$renderer->expects( $this->never() )->method( 'setTex' );
 
-		$this->assertEquals( $renderer->checkTex(), true );
+		$this->assertEquals( $renderer->checkTeX(), true );
 		// we don't mark a object as checked even though we rely on the database cache
 		// so readFromDatabase will be called again
-		$this->assertEquals( $renderer->checkTex(), true );
+		$this->assertEquals( $renderer->checkTeX(), true );
 	}
 }
