@@ -1,7 +1,13 @@
 <?php
+
 /**
  * Test the TeX source output format.
+ *
+ * @covers MathRenderer
+ *
  * @group Math
+ *
+ * @licence GNU GPL v2+
  */
 class MathSourceTest extends MediaWikiTestCase {
 
@@ -10,7 +16,7 @@ class MathSourceTest extends MediaWikiTestCase {
 	 * i.e. if the span element is generated right.
 	 */
 	public function testBasics() {
-		$real = MathRenderer::renderMath( "a+b", array(), 'source' );
+		$real = MathRenderer::renderMath( "a+b", [], 'source' );
 		$this->assertEquals(
 			'<span class="mwe-math-fallback-source-inline tex" dir="ltr">$ a+b $</span>',
 			$real,
@@ -22,7 +28,7 @@ class MathSourceTest extends MediaWikiTestCase {
 	 * Checks if newlines are converted to spaces correctly.
 	 */
 	public function testNewLines() {
-		$real = MathRenderer::renderMath( "a\n b", array(), 'source' );
+		$real = MathRenderer::renderMath( "a\n b", [], 'source' );
 		$this->assertSame(
 			'<span class="mwe-math-fallback-source-inline tex" dir="ltr">$ a  b $</span>',
 			$real,
